"""Visualization utilities for ChronoEEG."""

from chronoeeg.visualization.plots import (
    plot_epochs,
    plot_feature_importance,
    plot_fmm_components,
    plot_quality_metrics,
    plot_signal,
    plot_spectrogram,
)

__all__ = [
    "plot_signal",
    "plot_epochs",
    "plot_quality_metrics",
    "plot_feature_importance",
    "plot_fmm_components",
    "plot_spectrogram",
]
